# mos-math
[![](https://img.shields.io/pypi/v/mos-math?color=green)](https://pypi.org/project/mos-math/)[![license](https://img.shields.io/badge/license-BSD-red.svg)](https://www.freebsd.org/doc/en/articles/bsdl-gpl/article.html)


MOS mathematics for doctoral thesis

[Electrophysical properties of the MOS structure with implanted bulk](https://github.com/vbotka/thesis)
